@@ -26,6 +26,7 @@ import time
 from calendar import timegm
 from copy import deepcopy
 from datetime import datetime
+from datetime import timedelta
 from distutils.version import LooseVersion
 from monasca_agent.collector.checks import AgentCheck
 from monasca_agent.collector.virt import inspector
@@ -50,6 +51,13 @@ class LibvirtCheck(AgentCheck):
                                                     'libvirt_instances.json')
         self.metric_cache_file = "{0}/{1}".format(self.init_config.get('cache_dir'),
                                                   'libvirt_metrics.json')
+        self.use_bits = self.init_config.get('network_use_bits')
+        if self.init_config.get('disk_collection_period'):
+            self._disk_collection_period = int(self.init_config.get('disk_collection_period'))
+            self._last_disk_collect_time = datetime.fromordinal(1)
+        else:
+            self._disk_collection_period = 0
+        self._skip_disk_collection = False
 
     def _test_vm_probation(self, created):
         """Test to see if a VM was created within the probation period.
@@ -63,6 +71,20 @@ class LibvirtCheck(AgentCheck):
         probation_time = self.init_config.get('vm_probation', 300) - created_sec
         return int(probation_time)
 
+    def _get_metric_name(self, orig_name):
+        # Rename "tx" to "out" and "rx" to "in"
+        metric_name = orig_name.replace("tx", "out").replace("rx", "in")
+        if self.use_bits:
+            metric_name = metric_name.replace("bytes", "bits")
+        return metric_name
+
+    @staticmethod
+    def _get_metric_rate_name(metric_name):
+        """Change the metric name to a rate, i.e. "net.rx_bytes"
+        gets converted to "net.rx_bytes_sec"
+        """
+        return "{0}_sec".format(metric_name)
+
     @staticmethod
     def _validate_secgroup(cache, instance, source_ip):
         """Search through an instance's security groups for pingability
@@ -72,10 +94,10 @@ class LibvirtCheck(AgentCheck):
                 if ((secgroup['tenant_id'] == instance.tenant_id and
                      secgroup['name'] == instance_secgroup['name'])):
                     for rule in secgroup['security_group_rules']:
-                        if ((rule['remote_ip_prefix'] and
-                             rule['protocol'] == 'icmp' and
-                             all_matching_cidrs(source_ip,
-                                                [rule['remote_ip_prefix']]))):
+                        if rule['protocol'] == 'icmp':
+                            if ((not rule['remote_ip_prefix'] or
+                                 all_matching_cidrs(source_ip,
+                                                    [rule['remote_ip_prefix']]))):
                                 return True
 
     def _update_instance_cache(self):
@@ -114,6 +136,7 @@ class LibvirtCheck(AgentCheck):
                               "Either no VMs are present, or routing is centralized.")
 
         for instance in instances:
+            instance_ports = []
             inst_name = instance.__getattr__('OS-EXT-SRV-ATTR:instance_name')
             inst_az = instance.__getattr__('OS-EXT-AZ:availability_zone')
             if instance.flavor['id'] in flavor_cache:
@@ -121,6 +144,8 @@ class LibvirtCheck(AgentCheck):
             else:
                 inst_flavor = nova_client.flavors.get(instance.flavor['id'])
                 flavor_cache[instance.flavor['id']] = inst_flavor
+            if port_cache:
+                instance_ports = [p['id'] for p in port_cache if p['device_id'] == instance.id]
             id_cache[inst_name] = {'instance_uuid': instance.id,
                                    'hostname': instance.name,
                                    'zone': inst_az,
@@ -128,58 +153,22 @@ class LibvirtCheck(AgentCheck):
                                    'tenant_id': instance.tenant_id,
                                    'vcpus': inst_flavor.vcpus,
                                    'ram': inst_flavor.ram,
-                                   'disk': inst_flavor.disk}
+                                   'disk': inst_flavor.disk,
+                                   'instance_ports': instance_ports}
 
-            if self.init_config.get('metadata'):
-                for metadata in self.init_config.get('metadata'):
-                    if instance.metadata.get(metadata):
-                        id_cache[inst_name][metadata] = (instance.metadata.
-                                                         get(metadata))
+            for config_var in ['metadata', 'customer_metadata']:
+                if self.init_config.get(config_var):
+                    for metadata in self.init_config.get(config_var):
+                        if instance.metadata.get(metadata):
+                            id_cache[inst_name][metadata] = (instance.metadata.
+                                                             get(metadata))
 
             # Build a list of pingable IP addresses attached to this VM and the
             # appropriate namespace, for use in ping tests
             if netns:
                 secgroup_cache = nu.list_security_groups()['security_groups']
-                # Find all active fixed IPs for this VM, fetch each subnet_id
-                for net in instance.addresses:
-                    for ip in instance.addresses[net]:
-                        if ip['OS-EXT-IPS:type'] == 'fixed':
-                            subnet_id = None
-                            nsuuid = None
-                            for port in port_cache:
-                                if ((port['mac_address'] == ip['OS-EXT-IPS-MAC:mac_addr']
-                                     and port['tenant_id'] == instance.tenant_id
-                                     and port['status'] == 'ACTIVE')):
-                                    for fixed in port['fixed_ips']:
-                                        if fixed['ip_address'] == ip['addr']:
-                                            subnet_id = fixed['subnet_id']
-                                            break
-                            # Use the subnet_id to find the router
-                            ping_allowed = False
-                            if subnet_id is not None:
-                                for port in port_cache:
-                                    if ((port['device_owner'].startswith('network:router_interface')
-                                         and port['tenant_id'] == instance.tenant_id
-                                         and port['status'] == 'ACTIVE')):
-                                        nsuuid = port['device_id']
-                                        for fixed in port['fixed_ips']:
-                                            if fixed['subnet_id'] == subnet_id:
-                                                # Validate security group
-                                                if self._validate_secgroup(secgroup_cache,
-                                                                           instance,
-                                                                           fixed['ip_address']):
-                                                    ping_allowed = True
-                                                    break
-                                    if nsuuid is not None:
-                                        break
-                            if nsuuid is not None and ping_allowed:
-                                if 'network' not in id_cache[inst_name]:
-                                    id_cache[inst_name]['network'] = []
-                                id_cache[inst_name]['network'].append({'namespace': "qrouter-{0}".format(nsuuid),
-                                                                       'ip': ip['addr']})
-                            elif ping_allowed is False:
-                                self.log.debug("ICMP disallowed for {0} on {1}".format(inst_name,
-                                                                                       ip['addr']))
+                self._build_ip_list(instance, inst_name,
+                                    secgroup_cache, port_cache, id_cache)
 
         id_cache['last_update'] = int(time.time())
 
@@ -194,6 +183,48 @@ class LibvirtCheck(AgentCheck):
 
         return id_cache
 
+    def _build_ip_list(self, instance, inst_name, secgroup_cache, port_cache, id_cache):
+        # Find all active fixed IPs for this VM, fetch each subnet_id
+        for net in instance.addresses:
+            for ip in instance.addresses[net]:
+                if ip['OS-EXT-IPS:type'] == 'fixed' and ip['version'] == 4:
+                    subnet_id = None
+                    nsuuid = None
+                    for port in port_cache:
+                        if ((port['mac_address'] == ip['OS-EXT-IPS-MAC:mac_addr'] and
+                             port['tenant_id'] == instance.tenant_id and
+                             port['status'] == 'ACTIVE')):
+                            for fixed in port['fixed_ips']:
+                                if fixed['ip_address'] == ip['addr']:
+                                    subnet_id = fixed['subnet_id']
+                                    break
+                    # Use the subnet_id to find the router
+                    ping_allowed = False
+                    if subnet_id is not None:
+                        for port in port_cache:
+                            if ((port['device_owner'].startswith('network:router_interface') and
+                                 port['tenant_id'] == instance.tenant_id and
+                                 port['status'] == 'ACTIVE')):
+                                nsuuid = port['device_id']
+                                for fixed in port['fixed_ips']:
+                                    if fixed['subnet_id'] == subnet_id:
+                                        # Validate security group
+                                        if self._validate_secgroup(secgroup_cache,
+                                                                   instance,
+                                                                   fixed['ip_address']):
+                                            ping_allowed = True
+                                            break
+                            if nsuuid is not None:
+                                break
+                    if nsuuid is not None and ping_allowed:
+                        if 'network' not in id_cache[inst_name]:
+                            id_cache[inst_name]['network'] = []
+                        id_cache[inst_name]['network'].append({'namespace': "qrouter-{0}".format(nsuuid),
+                                                               'ip': ip['addr']})
+                    elif ping_allowed is False:
+                        self.log.debug("ICMP disallowed for {0} on {1}".format(inst_name,
+                                                                               ip['addr']))
+
     def _load_instance_cache(self):
         """Load the cache map of instance names to Nova data.
            If the cache does not yet exist or is damaged, (re-)build it.
@@ -250,11 +281,17 @@ class LibvirtCheck(AgentCheck):
 
     def _inspect_network(self, insp, inst, instance_cache, metric_cache, dims_customer, dims_operations):
         """Inspect network metrics for an instance"""
-
         inst_name = inst.name()
         for vnic in insp.inspect_vnics(inst):
             sample_time = time.time()
             vnic_dimensions = {'device': vnic[0].name}
+            instance_ports = instance_cache.get(inst_name)['instance_ports']
+            partial_port_id = vnic[0].name.split('tap')[1]
+            # Multiple networked guest
+            for port in instance_ports:
+                if partial_port_id == port[:11]:
+                    vnic_dimensions['port_id'] = port
+                    break
             for metric in vnic[1]._fields:
                 metric_name = "net.{0}".format(metric)
                 if metric_name not in metric_cache[inst_name]:
@@ -262,8 +299,12 @@ class LibvirtCheck(AgentCheck):
 
                 value = int(vnic[1].__getattribute__(metric))
                 if vnic[0].name in metric_cache[inst_name][metric_name]:
-                    val_diff = value - metric_cache[inst_name][metric_name][vnic[0].name]['value']
-                    if val_diff < 0:
+                    last_update_time = metric_cache[inst_name][metric_name][vnic[0].name]['timestamp']
+                    time_diff = sample_time - float(last_update_time)
+                    rate_value = self._calculate_rate(value,
+                                                      metric_cache[inst_name][metric_name][vnic[0].name]['value'],
+                                                      time_diff)
+                    if rate_value < 0:
                         # Bad value, save current reading and skip
                         self.log.warn("Ignoring negative network sample for: "
                                       "{0} new value: {1} old value: {2}"
@@ -273,24 +314,39 @@ class LibvirtCheck(AgentCheck):
                             'timestamp': sample_time,
                             'value': value}
                         continue
-                    # Change the metric name to a rate, ie. "net.rx_bytes"
-                    # gets converted to "net.rx_bytes_sec"
-                    rate_name = "{0}_sec".format(metric_name)
-                    # Rename "tx" to "out" and "rx" to "in"
-                    rate_name = rate_name.replace("tx", "out")
-                    rate_name = rate_name.replace("rx", "in")
+                    rate_name = self._get_metric_rate_name(metric_name)
+                    rate_name = self._get_metric_name(rate_name)
+                    if self.use_bits:
+                        rate_value *= 8
                     # Customer
                     this_dimensions = vnic_dimensions.copy()
                     this_dimensions.update(dims_customer)
-                    self.gauge(rate_name, val_diff,
+                    self.gauge(rate_name, rate_value,
                                dimensions=this_dimensions,
                                delegated_tenant=instance_cache.get(inst_name)['tenant_id'],
                                hostname=instance_cache.get(inst_name)['hostname'])
                     # Operations (metric name prefixed with "vm."
                     this_dimensions = vnic_dimensions.copy()
                     this_dimensions.update(dims_operations)
-                    self.gauge("vm.{0}".format(rate_name), val_diff,
+                    self.gauge("vm.{0}".format(rate_name), rate_value,
                                dimensions=this_dimensions)
+                # Report raw counters.
+                mapped_name = self._get_metric_name(metric_name)
+                weighted_value = value
+                if self.use_bits:
+                    weighted_value = value * 8
+                # Customer
+                this_dimensions = vnic_dimensions.copy()
+                this_dimensions.update(dims_customer)
+                self.gauge(mapped_name, weighted_value,
+                           dimensions=this_dimensions,
+                           delegated_tenant=instance_cache.get(inst_name)['tenant_id'],
+                           hostname=instance_cache.get(inst_name)['hostname'])
+                # Operations (metric name prefixed with "vm.")
+                this_dimensions = vnic_dimensions.copy()
+                this_dimensions.update(dims_operations)
+                self.gauge("vm.{0}".format(mapped_name),
+                           weighted_value, dimensions=this_dimensions)
                 # Save this metric to the cache
                 metric_cache[inst_name][metric_name][vnic[0].name] = {
                     'timestamp': sample_time,
@@ -302,28 +358,37 @@ class LibvirtCheck(AgentCheck):
         inst_name = inst.name()
         sample_time = float("{:9f}".format(time.time()))
         if 'cpu.time' in metric_cache[inst_name]:
-            # I have a prior value, so calculate the rate & push the metric
-            cpu_diff = insp.inspect_cpus(inst).time - metric_cache[inst_name]['cpu.time']['value']
+            cpu_info = insp.inspect_cpus(inst)
+            # I have a prior value, so calculate the raw_perc & push the metric
+            cpu_diff = cpu_info.time - metric_cache[inst_name]['cpu.time']['value']
             time_diff = sample_time - float(metric_cache[inst_name]['cpu.time']['timestamp'])
             # Convert time_diff to nanoseconds, and calculate percentage
-            rate = (cpu_diff / (time_diff * 1000000000)) * 100
-            if rate < 0:
+            raw_perc = (cpu_diff / (time_diff * 1000000000)) * 100
+            # Divide by the number of cores to normalize the percentage
+            normalized_perc = (raw_perc / cpu_info.number)
+            if raw_perc < 0:
                 # Bad value, save current reading and skip
                 self.log.warn("Ignoring negative CPU sample for: "
                               "{0} new cpu time: {1} old cpu time: {2}"
                               .format(inst_name, insp.inspect_cpus(inst).time,
                                       metric_cache[inst_name]['cpu.time']['value']))
                 metric_cache[inst_name]['cpu.time'] = {'timestamp': sample_time,
-                                                       'value': insp.inspect_cpus(inst).time}
+                                                       'value': cpu_info.time}
                 return
 
-            self.gauge('cpu.utilization_perc', int(round(rate, 0)),
+            self.gauge('cpu.utilization_perc', int(round(raw_perc, 0)),
                        dimensions=dims_customer,
                        delegated_tenant=instance_cache.get(inst_name)['tenant_id'],
                        hostname=instance_cache.get(inst_name)['hostname'])
-            self.gauge('vm.cpu.utilization_perc', int(round(rate, 0)),
+            self.gauge('cpu.utilization_norm_perc', int(round(normalized_perc, 0)),
+                       dimensions=dims_customer,
+                       delegated_tenant=instance_cache.get(inst_name)['tenant_id'],
+                       hostname=instance_cache.get(inst_name)['hostname'])
+            self.gauge('vm.cpu.utilization_perc', int(round(raw_perc, 0)),
                        dimensions=dims_operations)
-            self.gauge('vm.cpu.time_ms', insp.inspect_cpus(inst).time,
+            self.gauge('vm.cpu.utilization_norm_perc', int(round(normalized_perc, 0)),
+                       dimensions=dims_operations)
+            self.gauge('vm.cpu.time_ns', insp.inspect_cpus(inst).time,
                        dimensions=dims_operations)
 
         metric_cache[inst_name]['cpu.time'] = {'timestamp': sample_time,
@@ -333,23 +398,30 @@ class LibvirtCheck(AgentCheck):
         """Inspect disk metrics for an instance"""
 
         inst_name = inst.name()
+        metric_aggregate = {}
         for disk in insp.inspect_disks(inst):
             sample_time = time.time()
             disk_dimensions = {'device': disk[0].device}
             for metric in disk[1]._fields:
-                metric_name = "io.{0}".format(metric)
+                metric_name = "io.{0}".format(metric.replace('requests', 'ops'))
                 if metric_name not in metric_cache[inst_name]:
                     metric_cache[inst_name][metric_name] = {}
 
                 value = int(disk[1].__getattribute__(metric))
+                metric_aggregate[metric_name] = metric_aggregate.get(
+                    metric_name, 0) + value
                 if disk[0].device in metric_cache[inst_name][metric_name]:
-                    val_diff = value - metric_cache[inst_name][metric_name][disk[0].device]['value']
-                    if val_diff < 0:
+                    cached_val = metric_cache[inst_name][metric_name][disk[
+                        0].device]['value']
+                    last_update_time = metric_cache[inst_name][metric_name][disk[
+                        0].device]['timestamp']
+                    time_diff = sample_time - float(last_update_time)
+                    rate_value = self._calculate_rate(value, cached_val, time_diff)
+                    if rate_value < 0:
                         # Bad value, save current reading and skip
                         self.log.warn("Ignoring negative disk sample for: "
                                       "{0} new value: {1} old value: {2}"
-                                      .format(inst_name, value,
-                                              metric_cache[inst_name][metric_name][disk[0].device]['value']))
+                                      .format(inst_name, value, cached_val))
                         metric_cache[inst_name][metric_name][disk[0].device] = {
                             'timestamp': sample_time,
                             'value': value}
@@ -360,19 +432,87 @@ class LibvirtCheck(AgentCheck):
                     # Customer
                     this_dimensions = disk_dimensions.copy()
                     this_dimensions.update(dims_customer)
-                    self.gauge(rate_name, val_diff, dimensions=this_dimensions,
+                    self.gauge(rate_name, rate_value, dimensions=this_dimensions,
                                delegated_tenant=instance_cache.get(inst_name)['tenant_id'],
                                hostname=instance_cache.get(inst_name)['hostname'])
                     # Operations (metric name prefixed with "vm."
                     this_dimensions = disk_dimensions.copy()
                     this_dimensions.update(dims_operations)
-                    self.gauge("vm.{0}".format(rate_name), val_diff,
+                    self.gauge("vm.{0}".format(rate_name), rate_value,
+                               dimensions=this_dimensions)
+                    self.gauge("vm.{0}".format(metric_name), value,
                                dimensions=this_dimensions)
                 # Save this metric to the cache
                 metric_cache[inst_name][metric_name][disk[0].device] = {
                     'timestamp': sample_time,
                     'value': value}
 
+        this_dimensions = dict()
+        this_dimensions.update(dims_customer)
+        this_dimensions.update(dims_operations)
+        for metric in metric_aggregate:
+            sample_time = time.time()
+            rate_name = "vm.{0}_total_sec".format(metric)
+            if rate_name not in metric_cache[inst_name]:
+                metric_cache[inst_name][rate_name] = {}
+            else:
+                last_update_time = metric_cache[inst_name][
+                    rate_name]['timestamp']
+                time_diff = sample_time - float(last_update_time)
+                rate_value = self._calculate_rate(metric_aggregate[metric],
+                                                  metric_cache[inst_name][rate_name]['value'],
+                                                  time_diff)
+                if rate_value < 0:
+                    # Bad value, save current reading and skip
+                    self.log.warn("Ignoring negative disk sample for: "
+                                  "{0} new value: {1} old value: {2}"
+                                  .format(inst_name, metric_aggregate[metric],
+                                          metric_cache[inst_name][rate_name][
+                                              'value']))
+                    metric_cache[inst_name][rate_name] = {
+                        'timestamp': sample_time,
+                        'value': metric_aggregate[metric]}
+                    continue
+                self.gauge(rate_name, rate_value,
+                           dimensions=this_dimensions)
+            self.gauge("vm.{0}_total".format(metric), metric_aggregate[
+                metric], dimensions=this_dimensions)
+            # Save this metric to the cache
+            metric_cache[inst_name][rate_name] = {
+                'timestamp': sample_time,
+                'value': metric_aggregate[metric]}
+
+    def _inspect_disk_info(self, insp, inst, instance_cache, metric_cache,
+                           dims_customer, dims_operations):
+        """Inspect disk metrics for an instance"""
+
+        inst_name = inst.name()
+        metric_aggregate = {}
+        for disk in insp.inspect_disk_info(inst):
+            disk_dimensions = {'device': disk[0].device}
+            for metric in disk[1]._fields:
+                metric_name = "disk.{0}".format(metric)
+                value = int(disk[1].__getattribute__(metric))
+                metric_aggregate[metric_name] = metric_aggregate.get(
+                    metric_name, 0) + value
+                this_dimensions = disk_dimensions.copy()
+                this_dimensions.update(dims_customer)
+                self.gauge(metric_name, value, dimensions=this_dimensions,
+                           delegated_tenant=instance_cache.get(inst_name)['tenant_id'],
+                           hostname=instance_cache.get(inst_name)['hostname'])
+                # Operations (metric name prefixed with "vm."
+                this_dimensions = disk_dimensions.copy()
+                this_dimensions.update(dims_operations)
+                self.gauge("vm.{0}".format(metric_name), value,
+                           dimensions=this_dimensions)
+
+        this_dimensions = dict()
+        this_dimensions.update(dims_customer)
+        this_dimensions.update(dims_operations)
+        for metric in metric_aggregate:
+            self.gauge("vm.{0}_total".format(metric), metric_aggregate[
+                metric], dimensions=this_dimensions)
+
     def _inspect_state(self, insp, inst, instance_cache, dims_customer, dims_operations):
         """Look at the state of the instance, publish a metric using a
            user-friendly description in the 'detail' metadata, and return
@@ -399,6 +539,23 @@ class LibvirtCheck(AgentCheck):
 
         return dom_status
 
+    def prepare_run(self):
+        """Check if it is time for the disk measurements to be collected"""
+        # A separate disk collection period is optional
+        if self._disk_collection_period <= 0:
+            return
+
+        time_since_last = datetime.now() - self._last_disk_collect_time
+        # Handle times that are really close to the disk collection period
+        period_with_fudge_factor = timedelta(0, self._disk_collection_period - 1,
+                                             500000)
+        if time_since_last < period_with_fudge_factor:
+            self.log.debug('Skipping disk collection for %d seconds' %
+                           (self._disk_collection_period - time_since_last.seconds))
+            self._skip_disk_collection = True
+        else:
+            self._skip_disk_collection = False
+
     def check(self, instance):
         """Gather VM metrics for each instance"""
 
@@ -422,10 +579,17 @@ class LibvirtCheck(AgentCheck):
             agg_values[gauge] = 0
 
         insp = inspector.get_hypervisor_inspector()
+        updated_cache_this_time = False
         for inst in insp._get_connection().listAllDomains():
             # Verify that this instance exists in the cache.  Add if necessary.
             inst_name = inst.name()
-            if inst_name not in instance_cache:
+            if inst_name not in instance_cache and not updated_cache_this_time:
+                #
+                # If we have multiple ghost VMs, we'll needlessly
+                # update the instance cache.  Let's limit the cache
+                # update to once per agent wakeup.
+                #
+                updated_cache_this_time = True
                 instance_cache = self._update_instance_cache()
 
             # Build customer dimensions
@@ -442,6 +606,12 @@ class LibvirtCheck(AgentCheck):
                                           get(metadata))
                         if metadata_value:
                             dims_operations[metadata] = metadata_value
+                if self.init_config.get('customer_metadata'):
+                    for metadata in self.init_config.get('customer_metadata'):
+                        metadata_value = (instance_cache.get(inst_name).
+                                          get(metadata))
+                        if metadata_value:
+                            dims_customer[metadata] = metadata_value
                 # Remove customer 'hostname' dimension, this will be replaced by the VM name
                 del(dims_customer['hostname'])
             except TypeError:
@@ -475,9 +645,18 @@ class LibvirtCheck(AgentCheck):
             if inst_name not in metric_cache:
                 metric_cache[inst_name] = {}
 
-            self._inspect_cpu(insp, inst, instance_cache, metric_cache, dims_customer, dims_operations)
-            self._inspect_disks(insp, inst, instance_cache, metric_cache, dims_customer, dims_operations)
-            self._inspect_network(insp, inst, instance_cache, metric_cache, dims_customer, dims_operations)
+            if self.init_config.get('vm_cpu_check_enable'):
+                self._inspect_cpu(insp, inst, instance_cache, metric_cache, dims_customer, dims_operations)
+            if not self._skip_disk_collection:
+                self._last_disk_collect_time = datetime.now()
+                if self.init_config.get('vm_disks_check_enable'):
+                    self._inspect_disks(insp, inst, instance_cache, metric_cache, dims_customer,
+                                        dims_operations)
+                if self.init_config.get('vm_extended_disks_check_enable'):
+                    self._inspect_disk_info(insp, inst, instance_cache, metric_cache, dims_customer,
+                                            dims_operations)
+            if self.init_config.get('vm_network_check_enable'):
+                self._inspect_network(insp, inst, instance_cache, metric_cache, dims_customer, dims_operations)
 
             # Memory utilizaion
             # (req. balloon driver; Linux kernel param CONFIG_VIRTIO_BALLOON)
@@ -493,11 +672,13 @@ class LibvirtCheck(AgentCheck):
                                hostname=instance_cache.get(inst_name)['hostname'])
                     self.gauge("vm.{0}".format(name), mem_metrics[name],
                                dimensions=dims_operations)
+                memory_info = insp.inspect_memory_resident(inst)
+                self.gauge('vm.mem.resident_mb', float(memory_info.resident), dimensions=dims_operations)
             except KeyError:
                 self.log.debug("Balloon driver not active/available on guest {0} ({1})".format(inst_name,
                                                                                                instance_cache.get(inst_name)['hostname']))
             # Test instance's remote responsiveness (ping check) if possible
-            if self.init_config.get('ping_check') and 'network' in instance_cache.get(inst_name):
+            if (self.init_config.get('vm_ping_check_enable')) and self.init_config.get('ping_check') and 'network' in instance_cache.get(inst_name):
                 for net in instance_cache.get(inst_name)['network']:
 
                     ping_cmd = self.init_config.get('ping_check').replace('NAMESPACE',
@@ -526,3 +707,17 @@ class LibvirtCheck(AgentCheck):
         # Publish aggregate metrics
         for gauge in agg_gauges:
             self.gauge(agg_gauges[gauge], agg_values[gauge], dimensions=dims_base)
+
+    def _calculate_rate(self, current_value, cache_value, time_diff):
+        """Calculate rate based on current, cache value and time_diff."""
+        try:
+            rate_value = (current_value - cache_value) / time_diff
+        except ZeroDivisionError as e:
+            self.log.error("Time difference between current time and "
+                           "last_update time is 0 . {0}".format(e))
+            #
+            # Being extra safe here, in case we divide by zero
+            # just skip this reading with check below.
+            #
+            rate_value = -1
+        return rate_value
