@@ -310,6 +310,8 @@ class VCenterCheck(AgentCheck):
                     self.log.warn("No clusters configured to monitor")
                     return
                 self.session = self._get_api_session()
+                self.vc_uuid = (self.session.vim.service_content.
+                                about.instanceUuid)
                 self._ops = VcenterOperations(self.session,
                                               self._max_objects,
                                               self.log)
@@ -444,16 +446,12 @@ class VCenterCheck(AgentCheck):
             self.gauge(key, data.get(key), dimensions=dimensions)
             self.log.debug("Post metric data for %s,  %s: %d" %
                            (managed_cluster, key, data.get(key)))
-        # Additional metric for passive monitoring of ESX cluster
-        self.gauge("monasca.emit_time_sec", 0, dimensions=dimensions)
 
     def _get_dims(self, cluster, mor_id):
+        cluster_id = mor_id + "." + self.vc_uuid
         return {
             "vcenter_ip": self.vcenter_ip,
-            "cluster": cluster,
-            "host_type": "compute_node",
-            "role": "esx",
-            "id": cluster + "-" + self.vcenter_ip
+            "esx_cluster_id": cluster_id
         }
 
     @staticmethod
