@@ -1,3 +1,5 @@
+# (C) Copyright 2015 Hewlett Packard Enterprise Development Company LP
+
 import ast
 import logging
 import select
@@ -21,10 +23,7 @@ metric_class = {
 
 
 class Server(object):
-
-    """
-    A statsd udp server.
-    """
+    """A statsd udp server."""
 
     def __init__(self, aggregator, host, port, forward_to_host=None, forward_to_port=None):
         self.host = host
@@ -162,7 +161,7 @@ class Server(object):
                     name, value, metric_class[mtype], dimensions=dimensions, sample_rate=sample_rate)
 
     def start(self):
-        """ Run the server. """
+        """Run the server."""
         # Bind to the UDP socket.
         # IPv4 only
         open_socket = socket.socket(socket.AF_INET, socket.SOCK_DGRAM)
